### McAfee SIEM Command Line Interface and Python API
(Dev) [![Build Status](https://travis-ci.com/tristanlatr/msiem.svg?branch=master)](https://travis-ci.com/tristanlatr/msiem)

Based on the work of andywalen : https://github.com/andywalden

```
pip install msiem
msiem config --set auth
python3 setup.py test
```
